import { GetResponseDataTypeFromEndpointMethod } from "@octokit/types";
import * as github from "@actions/github";
declare type Octokit = ReturnType<typeof github.getOctokit>;
declare type WorkflowRun = GetResponseDataTypeFromEndpointMethod<Octokit["rest"]["actions"]["listWorkflowRuns"]>["workflow_runs"][number];
declare type Artifacts = GetResponseDataTypeFromEndpointMethod<Octokit["rest"]["actions"]["listWorkflowRunArtifacts"]>["artifacts"][number];
export declare type GetArtifactsForBranchAndWorkflowReturn = {
    artifact: Artifacts;
    workflowRun: WorkflowRun;
} | null;
export declare type GetArtifactsForBranchAndWorkflow = {
    owner: string;
    repo: string;
    branch: string;
    /**
     * The name of the workflow (e.g. the `name` key in the workflow, otherwise the root workflow name)
     */
    workflowName: string;
    /**
     * The name of the artifact
     */
    artifactName: string;
    /**
     * A specific commit sha to look for the artifact
     */
    commit?: string;
    /**
     * The number of results to query for
     */
    perPage?: number;
    /**
     * The max number of pages to query for
     */
    maxPages?: number;
    /**
     * Filter workflow runs by how the workflow was triggered. See the `event`
     * parameter here:
     * https://octokit.github.io/rest.js/v18#actions-list-workflow-runs
     */
    workflowEvent?: string;
};
/**
 * Fetch artifacts from a workflow run from a branch
 *
 * This is a bit hacky since GitHub Actions currently does not directly
 * support downloading artifacts from other workflows
 */
export declare function getArtifactsForBranchAndWorkflow(octokit: Octokit, { owner, repo, workflowName, branch, commit, artifactName, maxPages, perPage, workflowEvent, }: GetArtifactsForBranchAndWorkflow): Promise<GetArtifactsForBranchAndWorkflowReturn>;
export {};
